@@ -1,15 +1,16 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 __version__ = '$Id$'
 from tools.docco.rl_doc_utils import *
 from reportlab.platypus.tableofcontents import TableOfContents
 from datetime import datetime
 import reportlab
+from reportlab.rl_config import invariant
 
 title("ReportLab PDF Library")
 title("User Guide")
 centred('ReportLab Version ' + reportlab.Version)
-centred(datetime.now().strftime('Document generated on %Y/%m/%d %H:%M:%S %Z'))
+centred((datetime(2000,1,1,0,0,0) if invariant else datetime.now()).strftime('Document generated on %Y/%m/%d %H:%M:%S %Z'))
 
 nextTemplate("TOC")
 
@@ -189,11 +190,14 @@ Ben Echols,
 Benjamin Dumke,
 Benn B,
 Chad Miller, 
+Chris Buergi,
 Chris Lee, 
 Christian Jacobs, 
 Dinu Gherman,
+Edward Greve,
 Eric Johnson,
 Felix Labrecque,  
+Fubu @ bitbucket,
 Gary Poster, 
 Germán M. Bravo,
 Guillaume Francois, 
@@ -207,14 +211,17 @@ Jerome Alet,
 Jerry Casiano,
 Jorge Godoy,
 Keven D Smith,
+Kyle MacFarlane,
 Magnus Lie Hetland,
 Marcel Tromp, 
 Marius Gedminas,
+Mark de Wit,
 Matthew Duggan,
 Matthias Kirst,
 Matthias Klose,
 Max M, 
 Michael Egorov,
+Michael Spector,
 Mike Folwell,
 Mirko Dziadzka,
 Moshe Wagner,
@@ -228,15 +235,17 @@ Robert Alsina,
 Robert Hölzl,
 Robert Kern,
 Ron Peleg,
+Ruby Yocum,
 Simon King,
 Stephan Richter,
 Steve Halasz, 
+Stoneleaf @ bitbucket,
 T Blatter,
 Tim Roberts,
 Tomasz Swiderski,
 Ty Sarna,
 Volker Haas,
-Yoann Roman, 
+Yoann Roman,
 and many more.""")
 
 
